Some USB debug updates, mostly comments fixing, license header updates
and refactoring

Signed-off-by: Stefan Reinauer <stepan@coresystems.de>

Index: src/include/usbdebug_direct.h
===================================================================
--- src/include/usbdebug_direct.h	(revision 4441)
+++ src/include/usbdebug_direct.h	(working copy)
@@ -1,3 +1,20 @@
+/*
+ * This file is part of the coreboot project.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301 USA
+ */
+
 #ifndef USBDEBUG_DIRECT_H
 #define USBDEBUG_DIRECT_H
 
@@ -9,10 +26,12 @@
         unsigned endpoint_out;
         unsigned endpoint_in;
 };
+
 int dbgp_bulk_write_x(struct ehci_debug_info *dbg_info, const char *bytes, int size);
 int dbgp_bulk_read_x(struct ehci_debug_info *dbg_info, void *data, int size);
 void set_ehci_base(unsigned ehci_base);
 void set_ehci_debug(unsigned ehci_deug);
 unsigned get_ehci_debug(void);
 void set_debug_port(unsigned port);
+
 #endif
Index: src/console/usbdebug_direct_console.c
===================================================================
--- src/console/usbdebug_direct_console.c	(revision 4441)
+++ src/console/usbdebug_direct_console.c	(working copy)
@@ -1,3 +1,20 @@
+/*
+ * This file is part of the coreboot project.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301 USA
+ */
+
 #include <string.h>
 #include <console/console.h>
 #include <usbdebug_direct.h>
@@ -4,15 +20,19 @@
 #include <pc80/mc146818rtc.h>
 
-struct ehci_debug_info dbg_info;
+static struct ehci_debug_info dbg_info;
 
 void set_ehci_base(unsigned ehci_base)
 {
 	unsigned diff;
-	if(!dbg_info.ehci_debug) return;
+
+	if (!dbg_info.ehci_debug)
+		return;
+
 	diff = dbg_info.ehci_caps - ehci_base;
 	dbg_info.ehci_regs -= diff;
 	dbg_info.ehci_debug -= diff;
 	dbg_info.ehci_caps = ehci_base;
 }
+
 void set_ehci_debug(unsigned ehci_debug)
 {
@@ -21,39 +42,46 @@
 
 unsigned get_ehci_debug(void)
 {
-       return dbg_info.ehci_debug;
+	return dbg_info.ehci_debug;
 }
 
 static void dbgp_init(void)
 {
 	struct ehci_debug_info *dbg_infox;
-	dbg_infox = (struct ehci_debug_info *)((CONFIG_LB_MEM_TOPK<<10) - sizeof (struct ehci_debug_info)); //in RAM
-	memcpy(&dbg_info, dbg_infox, sizeof(struct ehci_debug_info) );
+
+	/* At this point, all we have to do is copy the fixed address
+	 * debug_info data structure to our version defined above. */
+
+	dbg_infox = (struct ehci_debug_info *)
+		((CONFIG_LB_MEM_TOPK << 10) - sizeof(struct ehci_debug_info));
+
+	memcpy(&dbg_info, dbg_infox, sizeof(struct ehci_debug_info));
 }
 
-static void dbgp_tx_byte(unsigned char data) 
+static void dbgp_tx_byte(unsigned char data)
 {
-	if(dbg_info.ehci_debug) 
-		dbgp_bulk_write_x(&dbg_info,&data,1);
+	if (dbg_info.ehci_debug)
+		dbgp_bulk_write_x(&dbg_info, &data, 1);
 }
 
-static unsigned char dbgp_rx_byte(void) 
+static unsigned char dbgp_rx_byte(void)
 {
 	unsigned char data = 0xff;
-	if(dbg_info.ehci_debug) 
-		dbgp_bulk_read_x(&dbg_info,&data,1);
+
+	if (dbg_info.ehci_debug)
+		dbgp_bulk_read_x(&dbg_info, &data, 1);
+
 	return data;
 }
 
-static int dbgp_tst_byte(void) 
+static int dbgp_tst_byte(void)
 {
 	return dbg_info.ehci_debug;
 }
 
 static const struct console_driver usbdebug_direct_console __console = {
-	.init    = dbgp_init,
-	.tx_byte = dbgp_tx_byte,
-	.rx_byte = dbgp_rx_byte,
+	.init     = dbgp_init,
+	.tx_byte  = dbgp_tx_byte,
+	.rx_byte  = dbgp_rx_byte,
 	.tst_byte = dbgp_tst_byte,
 };
-
Index: src/lib/usbdebug_direct.c
===================================================================
--- src/lib/usbdebug_direct.c	(revision 4441)
+++ src/lib/usbdebug_direct.c	(working copy)
@@ -1,10 +1,22 @@
 /*
+ * This file is part of the coreboot project.
+ *
  * Copyright (C) 2006 Eric Biederman (ebiederm@xmission.com)
  *
- *	This program is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU General Public License version
- *	2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301 USA
+ */
+/*
  *	2006.12.10 yhlu moved it to corbeoot and use struct instead
  */
 #ifndef __ROMCC__
@@ -15,7 +27,6 @@
 #endif
 #endif
 
-
 #include <arch/io.h>
 
 #include <usb_ch9.h>
Index: src/pc80/usbdebug_direct_serial.c
===================================================================
--- src/pc80/usbdebug_direct_serial.c	(revision 4441)
+++ src/pc80/usbdebug_direct_serial.c	(working copy)
@@ -1,24 +1,52 @@
+/*
+ * This file is part of the coreboot project.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301 USA
+ */
+
 #include <part/fallback_boot.h>
-#include "../lib/usbdebug_direct.c" 
+#include "../lib/usbdebug_direct.c"
+
 static void early_usbdebug_direct_init(void)
 {
-	struct ehci_debug_info *dbg_info = 
-		(struct ehci_debug_info *)(CONFIG_DCACHE_RAM_BASE + CONFIG_DCACHE_RAM_SIZE - sizeof (struct ehci_debug_info)); 
-	
-	usbdebug_direct_init(EHCI_BAR, EHCI_DEBUG_OFFSET, dbg_info); 
+	struct ehci_debug_info *dbg_info = (struct ehci_debug_info *)
+	    (CONFIG_DCACHE_RAM_BASE + CONFIG_DCACHE_RAM_SIZE - sizeof(struct ehci_debug_info));
+
+	usbdebug_direct_init(EHCI_BAR, EHCI_DEBUG_OFFSET, dbg_info);
 }
+
 void usbdebug_direct_tx_byte(unsigned char data)
 {
 	struct ehci_debug_info *dbg_info;
-	dbg_info = (struct ehci_debug_info *)(CONFIG_DCACHE_RAM_BASE + CONFIG_DCACHE_RAM_SIZE - sizeof (struct ehci_debug_info)); // in Cache 
-	if (dbg_info->ehci_debug) { 
+
+	/* "Find" dbg_info structure in Cache */
+	dbg_info = (struct ehci_debug_info *)
+	    (CONFIG_DCACHE_RAM_BASE + CONFIG_DCACHE_RAM_SIZE - sizeof(struct ehci_debug_info));
+
+	if (dbg_info->ehci_debug) {
 		dbgp_bulk_write_x(dbg_info, &data, 1);
 	}
 }
+
 void usbdebug_direct_ram_tx_byte(unsigned char data)
 {
 	struct ehci_debug_info *dbg_info;
-	dbg_info = (struct ehci_debug_info *)((CONFIG_LB_MEM_TOPK<<10) - sizeof (struct ehci_debug_info)); //in RAM 
+
+	/* "Find" dbg_info structure in RAM */
+	dbg_info = (struct ehci_debug_info *)
+	    ((CONFIG_LB_MEM_TOPK << 10) - sizeof(struct ehci_debug_info));
+
 	if (dbg_info->ehci_debug) {
 		dbgp_bulk_write_x(dbg_info, &data, 1);
 	}
